@@ -33,7 +33,7 @@ class GraphAPI(object):
         response = self._query('GET', path, options, page)
 
         if response is False:
-            raise self.Error('Could not get "%s".' % path)
+            raise self.FacebookError('Could not get "%s".' % path)
 
         return response
 
@@ -51,7 +51,7 @@ class GraphAPI(object):
         response = self._query('POST', path, data)
 
         if response is False:
-            raise self.Error('Could not post to "%s"' % path)
+            raise self.FacebookError('Could not post to "%s"' % path)
 
         return response
 
@@ -65,7 +65,7 @@ class GraphAPI(object):
         response = self._query('DELETE', path)
 
         if response is False:
-            raise self.Error('Could not delete "%s"' % path)
+            raise self.FacebookError('Could not delete "%s"' % path)
 
         return response
 
@@ -104,23 +104,27 @@ class GraphAPI(object):
 
         :param requests: A list of dictionaries with keys 'method', 'relative_url' and optionally 'body'.
 
-        Yields a list of responses and/or GraphAPI.Error instances.
+        Yields a list of responses and/or GraphAPI.FacebookError, GraphAPI.HTTPError instances.
         """
         responses = self.post(
             batch = json.dumps(requests)
         )
 
         for response, request in zip(responses, requests):
-            data = json.loads(response['body'])
+            if response:
+                data = json.loads(response['body'])
+            else:
+                yield None
+                continue
 
             if not response['code'] == 200:
-                yield self.Error(
+                yield self.FacebookError(
                     '{type} error on {method} "{path}": {msg}.'.format(
                         type = data['error']['type'],
                         method = request['method'],
                         path = request['relative_url'],
                         msg = data['error']['message']
-                    )
+                    ), data['error']['code']
                 )
 
                 continue
@@ -141,7 +145,12 @@ class GraphAPI(object):
 
         def load(method, url, data):
             if method in ['GET', 'DELETE']:
-                response = requests.request(method, url, params=data, allow_redirects=True)
+
+                try:
+                    response = requests.request(method, url, params=data, allow_redirects=True)
+                except requests.RequestException as exception:
+                    raise self.HTTPError(exception.message)
+
 
             if method in ['POST', 'PUT']:
                 files = {}
@@ -153,7 +162,10 @@ class GraphAPI(object):
                 for key in files:
                     data.pop(key)
 
-                response = requests.request(method, url, data=data, files=files)
+                try:
+                    response = requests.request(method, url, data=data, files=files)
+                except requests.RequestException as exception:
+                    raise self.HTTPError(exception.message)
 
             result = self._parse(response.content)
 
@@ -208,11 +220,11 @@ class GraphAPI(object):
         # as to the prerequisites for this type of response, though it seems that it responds with 'true'
         # when objects are successfully deleted and 'false' upon attempting to delete or access an item that
         # one does not have access to.
-        # 
+        #
         # For example, the API would respond with 'false' upon attempting to query a feed item without having
         # the 'read_stream' extended permission. If you were to query the entire feed, however, it would respond
         # with an empty list instead.
-        # 
+        #
         # Genius.
         #
         # We'll handle this discrepancy as gracefully as we can by implementing logic to deal with this behavior
@@ -220,9 +232,19 @@ class GraphAPI(object):
         if type(data) is dict:
 
             if 'error' in data:
-                raise self.Error(data['error']['message'])
+                raise self.FacebookError(data['error']['message'], data['error']['code'])
+            if 'error_msg' in data:
+                raise self.FacebookError(data['error_msg'], data['error_code'])
 
         return data
 
-    class Error(FacepyError):
-        pass
+    class FacebookError(FacepyError):
+        """Exception for errors returned by the Graph API."""
+
+        def __init__(self, message, code):
+            super(GraphAPI.FacebookError, self).__init__(message)
+
+            self.code = code
+
+    class HTTPError(FacepyError):
+        """Exception for transport errors."""
